Details

## Cookies must be allowed.

Your browser is currently set to block cookies. Your browser must allow cookies before you can use this application.

Cookies are small text files stored on your computer that tell this application when you're signed in. To learn how to allow cookies, see online help in your web browser.

## You are using a web browser which this application no longer supports.

We support the current and previous major releases of Google Chrome, Firefox, Internet Explorer, and Safari on a rolling basis. Each time a new version is released, we begin supporting that version and stop supporting the third most recent version.

## Supported Browsers

Chrome for Business
Firefox
Internet Explorer
Apple Safari

Internet Explorer 9 Users Internet Explorer 11 launched on October 17, 2013, and as a result, we've discontinued support for Internet Explorer 9.

Organizations that depend on old versions of Internet Explorer may want to consider a dual browser strategy.

# Smart Search

### *Required

One or more fields was completed incorrectly:

## Search Criteria

Type the record number in the search criteria field. To perform a wildcard search using a case number, enter at least four characters.
You can also type a name in Last, First Middle Suffix format. To perform a wildcard search, type a minimum of three characters followed by an asterisk for the last name, and a minimum of one character followed by an asterisk for the first name.
For a precision search, click Advanced Filtering Options to expand additional search fields.
To search for a case by a business name, click Advanced Filtering Options, navigate to the General Options section, and select "Business Name" from the Filter by Search Type drop-down list. Type the business name in the search field above, and click Submit. Or use the Smart Search; if the business name includes a comma use a wildcard search by adding an * in place of the comma. Do not add anything after the *.

* Enter a Record Number or Name in Last, First Middle Suffix Format

select

* Enter a Last Name
* Enter a First Name
Enter a Middle Name
select
Please select a valid name Suffix

Advanced Filtering Options

# General Options

## Filter by Location

select

## Filter by Search Type

select

## Include

- Cases

##

# Party Search Criteria

## Search by

Party Name
Nickname

Business Name

Sounds Like

Filter by Date of Birth From
Filter by Date of Birth To
select
Filter by Gender
select
Filter by Ethnicity
Filter by FBI Number
Filter by SO Number
Filter by Booking Number

# Case Search Criteria

select
Filter by Case Type
select
Filter by Case Status
Filter by File Date Start
Filter by File Date End
select
Filter by Judicial Officer

# Cases

| Case Number | Style / Defendant | File Date | Status | Party Name
--- | --- | --- | --- | --- | ---
| 19D67383 | Arthur Johnson VS JARROD LAKE,PAULA MOORE | 01/02/2019 | Closed | LAKE, JARROD

#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Financial
Documents
Print

# Case Information

19D67383 | Arthur Johnson VS JARROD LAKE,PAULA MOORE

Case Number
19D67383

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
01/02/2019

Case Type
Magistrate Dispossessory - Non Payment of Rent

Case Status
Closed

# Party

Plaintiff
Johnson, Arthur

Address

3000 Kelley Chapel RD
Decatur GA 30034

Active Attorneys

Pro Se

Defendant
LAKE, JARROD

Address

2755 KNOLLIGEN DR
DECATUR GA 30034

Active Attorneys

Pro Se

Defendant
MOORE, PAULA

# Disposition Events

01/28/2019 Judgment

View Document Dismissed with Prejudice

Judicial Officer
Jones, Lindsay RM

Judgment Type
Dismissed with Prejudice

# Events and Hearings

- 12/04/2018 Tack and Mail Service

  View Document Tack and Mail Service

  Comment
  answer due by January 11, 2019

- 01/02/2019 Dispossessory Warrant

  View Document Dispossessory Warrant

- 01/02/2019 Dispossessory Service

  Served
  01/04/2019

  Anticipated Server
  Marshal

  Anticipated Method

  Served
  01/04/2019

  Anticipated Server
  Marshal

  Anticipated Method

- 01/11/2019 Dispossessory Answer

  View Document Dispossessory Answer

- 01/28/2019 Dispossessory Pro Se

  View Document Dispo Hearing Notice

  View Document Dispo Hearing Notice

  View Document Dispo Hearing Notice

  Judicial Officer
  Anderson, Berryl A

  Hearing Time
  9:00 AM

- 02/11/2019 Returned from Post Office

# Financial

Johnson, Arthur

Total Financial Assessment
$124.00
Total Payments and Credits
$124.00

Date | Description | Receipt | Payer Name | Amount
--- | --- | --- | --- | ---
1/1/2019 | Transaction Assessment |  |  | $124.00
1/1/2019 | Mag-Payment | Receipt # 2019-00013 | Johnson, Arthur | ($124.00)

# Documents

View Document Dispossessory Warrant

View Document Dispo Hearing Notice

View Document Dispo Hearing Notice

View Document Dispo Hearing Notice

View Document Dispossessory Answer

View Document Tack and Mail Service

View Document Dismissed with Prejudice

Machine: IT-ODYPORT-WP1

## Are you still here?

Your session will expire in 60 seconds due to inactivity.

»

- Adams, Gregory A.
- Alexander, Kimberly A
- Anderson, Berryl A
- Anderson, Kimberly
- Axam, Cinque M
- Barrie, Tangela
- Bethel, Winston P
- Boulee, J. P.
- Bratton-Haynes, Linda
- Case, No Billed
- Cash, Mary M.
- Castellani, Robert J.
- Coursey, Daniel M., Jr.
- Crawford, Vincent C
- DA, Decline
- Davis-Baugh, Roshonda
- Dear Jackson, LaTisha
- Edgerton, K Tyler
- El-Amin, Fatima
- El-Amin, Fatima
- Flake, Gail C.
- Foxworth, Richard C.
- Freeman, J Caroline
- Fuller, Hilton M.
- Gordon, Janis C.
- Grayson, Janet
- Guy, September
- Haddad, Juwayn
- Hancock, Michael E.
- Hargrove, Bedelia C
- Harvey, Alan C.
- Hunter, Linda W.
- Hydrick, Stacey K.
- Indermark, Howard W.
- Jackson, Asha F.
- Jacobs, Mike
- Jason, Claire B.
- Johnson, Courtney L.
- Johnson, Marian
- Jones, Lindsay RM
- Judge, Unassigned MA
- Judge, Unassigned TN
- Koehler, Christine A
- Leshaw, Gary
- Lopez, Dax E
- Manheimer, Hollie
- McCoyd, Matthew J
- McLaughlin, Jack
- McMullin, Ruth
- McNeal, Shannon
- Miller, Curtis W
- Morales, Enrique
- Morris, Shondeana C
- Murry, Temika
- Neal, Joyce L
- Out of County, Judge
- Panos, Johnny
- Peagler, Desiree Sutton
- Polk, Nora
- Presiding, Judge
- Purdom, Wayne M
- Ramsey, Ronald, Sr.
- Robins, Mathew
- Rosh, Jeryl
- Ross, Brian K
- Sacks, Albert R
- Scott, Mark Anthony
- Scott, Sabrina
- Seeliger, Clarence F.
- SENIOR PRESIDING, JUDGE
- Sitting, Judge
- Spears, John
- Stephens, Corneill R
- Storey, Kiesha R
- Stroud, Rhathelia
- Taylor, Abbi S
- Williams, Phyllis R
- Wolk, Kelli
- Wong, Alvin T
- Wood, Charles D

- D. Ed. (Education)
- Doctor of Chiropract
- Doctor of Dentistry
- Doctor of Osteopathi
- Esquire
- II.
- III.
- IV.
- Jr.
- Juris Doctorate
- M.D.
- P.H.D.
- Registered Nurse
- Sr.
- V.
- VI.
- VII.
- VIII.

- All Courts
- DeKalb State and Magistrate Courts
- DeKalb Superior Courts

- Smart Search
- Attorney Bar Number
- Attorney Name
- Business Name
- Case Cross-Reference Number
- Case Number
- Citation Number
- Judicial Officer
- Nickname
- Party Name

- Female
- Male

- Asian
- Black
- Indian
- Multiracial
- Native Hawaiian or Other Pacific Islander
- Other
- Unavailable
- White

- All Case Types
- All Civil and Family Case Type
- All Criminal Case Types

- Accusation
- Acquittal and Discharge
- Admin Order Temporary Closure of Case
- Administration Order
- Administrative Closure
- Administratively Closed
- Administratively Closed
- Administratively Dismissed
- Alford Plea
- Amended Answer
- Amended Notice of Deposition
- Amended Notice of Deposition
- Answer and Counterclaim
- Answer and Cross Claim
- Answer Filed
- Answer to Counterclaim
- Answer to Cross Claim
- Appeal
- Appealed
- Application for Writ of Habeas
- Aquittal and Discharge
- Backing Order to Marshal
- Bankruptcy Stay
- Bench Trial
- Bench Trial
- Bench Trial Judgment for Defendant
- Bench Trial Judgment for Plaintiff
- Bench Trial Judgment for Plaintiff
- Bench Trial Judgment for Plaintiff
- Bench Trial on DUI Case
- Bench Trial on Misdemeanor Case
- Bench Verdict of Guilty
- Bench Verdict of Not Guilty
- Bench Verdict of Not Guilty
- Bench Warrant
- Bench Warrant Issued
- Bench Warrant Prepared
- Case Category Change
- Case Consolidation
- Case Consolidation
- Case Dismissal
- Case on Appeal
- Case Reactivated
- Case Review
- Case Transfer to Another Court
- Cash Bond Forfeiture
- Cash Bond Forfieture
- Check Pending Order
- Check/Leave to Next Calendar
- Closed
- Closed
- Closed
- Closed
- Closed - Appeals Remittitur
- Closed - Bench Trial Verdict Guilty
- Closed - Bench Trial Verdict Not Guilty
- Closed - Bench Warrant
- Closed - Dead Docket
- Closed - Drug Court
- Closed - Guilty Plea
- Closed - Jury Verdict Guilty
- Closed - Jury Verdict Not Guilty
- Closed - No Bill
- Closed - Nolle Prosse
- Closed - Transferred Out
- Compliance Hearing
- Conflict Case
- Consent
- Consent
- Consent Agreement
- Consent Agreement
- Consent Judgment
- Consent Order
- Consolidated
- Consolidated and Transferred
- Continuance
- Continuance
- Conversion-uCASE STATUS
- Cost Paid to Prepare Appeal
- Cost Paid to Prepart Appeal
- Cost Taken In As Trust
- Counterclaim
- Court Recusal
- Crossclaim
- Dead Docket
- Dead Docket
- Default Judgment
- Defendants Traverse
- Delayed Court Date Acknowledged
- Directed Verdict
- Directed Verdict
- Directed Verdict for Defendant
- Directed Verdict for Plaintiff
- Directed Verdict or Jnov
- Directed Verdict or JNOV
- Discovery
- Discovery
- Dismissal
- Dismissed
- Dismissed
- Dismissed
- Dismissed - For Want of Prosecution
- Dismissed - Involuntary
- Dismissed - Voluntary
- Dismissed - With Prejudice
- Dismissed - Without Prejudice
- Dismissed Involuntary
- Dismissed Involuntary
- Dismissed Voluntary
- Dismissed with Prejudice
- Disp/Dispute Resolution Program
- Duplicate Case
- E-File Open
- Expired 6 Months
- Expunged Record
- Felony Warrant Issued
- File Sent To Bookkeeping
- Filed
- Final Judgment
- Final Judgment
- Final Judgment and Decree
- Final Order
- Finalized Adoption
- First Offender Sentence
- First Offender Sentence
- Hold
- In Publication
- Indictment Filed
- Indictment/Accusation Filed
- JDTC Program Completed
- Judgment for Defendant
- Judgment For Plaintiff
- Judgment on Pleadings
- Judgment on Verdict
- Judgment on Verdict
- Judgment on Verdict
- Judgment Verdict for Defendant
- Jury Demand Filed
- Jury Trial
- Jury Trial on a DUI Case
- Jury Trial on a Traffic Case
- Jury Trial on Misdemeanor Case
- Jury Trial Settlement
- Jury Trial Settlement
- Jury Verdict for Defendant
- Jury Verdict for Plaintiff
- Jury Verdict for Plaintiff and Defendant
- Jury Verdict for Pltf
- Jury Verdict of Guilty
- Jury Verdict of Not Guilty
- Jury Verdict of Not Guilty
- Jury Verdict Of Not Guilty
- Juvenile Court Investigation
- Location April Peremptory
- Location August Motion
- Location August Non Jury
- Location August Peremptory
- Location Briefs
- Location DRC
- Location February Jury
- Location February Motions
- LOCATION FEBUARY PRETRIALS
- Location January Non Jury
- Location January Peremptory
- Location July Motions
- Location July Non Jury
- Location July Peremptory
- Location June Jury
- Location June Motions
- Location June Non Jury
- Location Jury Trial File
- Location March Pretrials
- Location May Jury
- Location May Motion
- Location November Non Jury
- Location October Non Jury
- Location October Peremeptory
- Location On Appeal
- Location Peremptory File
- Location September Jury
- Location September Non Jury
- Location September Pretrials
- LOCATION-DECEMBER JURY
- LOCATION-JUNE- PREEMPTORY
- Location-Jury Pretrials
- Magistrate To State Court Tran
- Motion for Default Judgment
- Motion for Default Judgment
- Multiple Parties/ Dispositions
- Multiple Parties/Dispositions
- No Accusation Filed
- No Accusations Filed
- No Bill of Indictment Filed
- Nolle Prosse
- Nolo Contendere
- Non- Jury Trial Disposition
- Not Guilty By Reason of Insaniry
- Not Presented to Grand Jury
- Notice- Case to be Reactivated
- Notice of Appeal
- Notice of Removal
- Notice of Removal
- Open
- Open
- Open
- Open Default
- Open with Judgment
- Order and Judgment
- Order For Continuance
- Order Granting Withdrawal
- Order Granting Withdrawal
- Order Staying Case
- Order to Dispute Resolution
- Order to Dispute Resolution Program
- Order Vacating/Setting Aside Judgment
- Paid and Satisfied
- Pauper's Request Filed
- Payment
- PAYMENT
- Pending
- Pending Pauper's
- Pending Service
- Personal Service
- Plea
- Plea in Absentia
- Pleas in Absentia
- Post Judgment Activity
- Principal and Deposit Paid by Defendant
- Principal Deposit Paid by Defendant
- Principle And Deposit Paid By Defendant
- Re- Indictment/ Re- Accusation Filed
- Rent Tendered
- Reopen
- Reopen - Bench Warrant
- Reopen - Dead Docket
- Reopen - Drug Court
- Reopen - Returned from Appeals
- Reopened
- Reopened Case
- Reopened Closed Case
- Rescheduled
- Reset Trial Date
- Restraining Order
- Returned to Clerk's Office
- Reviving a Dormant Judgment
- Revoked
- Satisfaction of Judgment
- Satisfaction Of Judgment
- Satisfaction/ Cancel of Judgment
- Scheduled To Be Nad Directed
- Scheduling Error
- Scheduling Error
- Scheduling Error - District Attorney
- Sent to Dispute Resolution
- Sentence
- Service by Acknowledgement
- Service By Agent
- Service By Second Original
- Service by Substitution
- Service By Tack and Mail
- Service Notorious
- Service on Secretary of State
- Service Perfected
- Service Perfected
- Settlement
- Settlement
- Settlement
- Special Master
- Stay For Bankruptcy
- Stay Pursuant to Bankruptcy
- Stipulation
- Stipulation
- Summary Judgment
- Summary Judgment
- Summary Judgment for Defendent
- Summary Judgment for Plaintiff
- Supersedeas Bond Posted
- Temporary Closure By Administrative Order
- To Be Scheduled for PHC
- To Judge
- To Law Clerk
- Transfer
- Transfer
- Transfer to Division
- Transfer to Solicitor's Office
- Transferred
- Transferred Case
- Transferred to Another Court
- Transferred to Another Jurisdiction
- Transferred to DA's Office
- Transferred to Division 1
- Transferred to Federal Court
- Transferred to Juvenile Court
- Transferred to Juvenile Court
- Transferred to State Court
- Traverse Filed
- Voluntary Dismissal
- Warrant Issued
- Writ Application Denied
- Writ Application Sent to Judge
- Writ Issued
- Writ Of Certiorari
- Writ of Habeas Corpus

- Adams, Gregory A.
- Alexander, Kimberly A
- Anderson, Berryl A
- Anderson, Kimberly
- Axam, Cinque M
- Barrie, Tangela
- Bethel, Winston P
- Boulee, J. P.
- Bratton-Haynes, Linda
- Case, No Billed
- Cash, Mary M.
- Castellani, Robert J.
- Coursey, Daniel M., Jr.
- Crawford, Vincent C
- DA, Decline
- Davis-Baugh, Roshonda
- Dear Jackson, LaTisha
- Edgerton, K Tyler
- El-Amin, Fatima
- El-Amin, Fatima
- Flake, Gail C.
- Foxworth, Richard C.
- Freeman, J Caroline
- Fuller, Hilton M.
- Gordon, Janis C.
- Grayson, Janet
- Guy, September
- Haddad, Juwayn
- Hancock, Michael E.
- Hargrove, Bedelia C
- Harvey, Alan C.
- Hunter, Linda W.
- Hydrick, Stacey K.
- Indermark, Howard W.
- Jackson, Asha F.
- Jacobs, Mike
- Jason, Claire B.
- Johnson, Courtney L.
- Johnson, Marian
- Jones, Lindsay RM
- Judge, Unassigned MA
- Judge, Unassigned TN
- Koehler, Christine A
- Leshaw, Gary
- Lopez, Dax E
- Manheimer, Hollie
- McCoyd, Matthew J
- McLaughlin, Jack
- McMullin, Ruth
- McNeal, Shannon
- Miller, Curtis W
- Morales, Enrique
- Morris, Shondeana C
- Murry, Temika
- Neal, Joyce L
- Out of County, Judge
- Panos, Johnny
- Peagler, Desiree Sutton
- Polk, Nora
- Presiding, Judge
- Purdom, Wayne M
- Ramsey, Ronald, Sr.
- Robins, Mathew
- Rosh, Jeryl
- Ross, Brian K
- Sacks, Albert R
- Scott, Mark Anthony
- Scott, Sabrina
- Seeliger, Clarence F.
- SENIOR PRESIDING, JUDGE
- Sitting, Judge
- Spears, John
- Stephens, Corneill R
- Storey, Kiesha R
- Stroud, Rhathelia
- Taylor, Abbi S
- Williams, Phyllis R
- Wolk, Kelli
- Wong, Alvin T
- Wood, Charles D